/* [Bolt holes in the corners] */

// Pick the size of the long threaded rods that run through
// the corners and hold everything together.
//
// Note: you should pick the same size and fudge factor
// for the ear parts.
// M4 = 2.00
bolt_size = 2.00;

// Make the bolt holes this much bigger than the size of the bolt
// to give a more comfortable fit
bolt_hole_fudge = 0.2;


/* [Hidden] */
// make the screw holes this much bigger than the
// actual screw for a more comfortable fit
// (a bigger number here will make the screws fit looser)
screw_hole_fudge = 0.15;
number_to_fit = 6;

height = 33.1423; // match the size of a 13 Pi rack
inner_width = 58;
outer_width = (450.85 - 20) / number_to_fit;
length = 90;

bolt_column_size = 12;

// epsilon is used to slightly overlap pieces to help the previewer
epsilon = 0.001;

bolt_radius = bolt_size + bolt_hole_fudge;

wall_thickness = (outer_width - inner_width) / 2;
back_wall_thickness = 5;
floor_depth = 3;
tray_depth = 5;
tray_slot_depth = 2.5;
spacer_depth = 3;

sd_window_width = 40;
sd_window_height = height - (tray_depth + floor_depth)*2;
pillar_width = 10;
floor_window_width = sd_window_width;
floor_window_border = (inner_width - floor_window_width) / 2;
floor_window_length = length - back_wall_thickness - floor_window_border - bolt_column_size;
port_window_width = length - 2*pillar_width;
pcb_height = floor_depth + tray_depth + spacer_depth;


//Readyformed: Thin cover over top. Note the 22 is top location set to "eat in" to the existing space so the lid is not above the bracket line.
  translate([ -epsilon,
                pillar_width-10,
                pcb_height+21]) {
        cube([  outer_width + 2*epsilon,
                port_window_width+20,
                height - pcb_height - tray_depth - floor_depth-12]);
    }



difference() {
    union() {
        // the main block
        cube([outer_width, length, height]);
        
        // the bolt columns
        translate([0, 0, floor_depth - bolt_column_size]) {
            cube([outer_width, bolt_column_size, bolt_column_size]);
        }
        translate([0, length-bolt_column_size, floor_depth - bolt_column_size]) {
            cube([outer_width, bolt_column_size, bolt_column_size]);
        }
    }

    // carve out the interior
    translate([wall_thickness, -epsilon, floor_depth]) {
        cube(  [inner_width,
                length - back_wall_thickness + epsilon,
                height - floor_depth + epsilon]);
    }

    // punch a hole for the sd card
    translate([ (outer_width - sd_window_width) / 2,
                length - back_wall_thickness - epsilon,
                tray_depth + floor_depth]) {
        cube([  sd_window_width,
                back_wall_thickness + 2*epsilon,
                height - 2*tray_depth - 2*floor_depth]);
    }

    // punch a hole for side port access
   //Readyformed: +4 added to raise height of hole to match increased rear hole.
    translate([ -epsilon,
                pillar_width,
                pcb_height]) {
        cube([  outer_width + 2*epsilon,
                port_window_width,
                height - pcb_height - tray_depth - floor_depth+4]);
    }




 // Readyformed - punch a hole to remove centre of mounting holes. Change 1 to larger number to remove front.
    translate([ -epsilon+10,
                1,
                pcb_height-25]) {
        cube([  outer_width /2 + 15,
                port_window_width*2-45,
                height - pcb_height - tray_depth - floor_depth]);
    }


 // Readyformed - punch a hole to remove back.
 // was height - pcb_height+6
    translate([ -epsilon+7,
                75,
                pcb_height-3]) {
        cube([  outer_width /2 +22,
                port_window_width/2,
                height - pcb_height+10 - tray_depth - floor_depth]);
    }

    // punch a hole in the bottom
    translate([ wall_thickness + floor_window_border,
                bolt_column_size,
                -epsilon]) {
        cube([  floor_window_width,
                floor_window_length,
                floor_depth + 2*epsilon]);
    }
    
    
    
    // open a groove that the speaker jack can slide through
   //Readyformed: height 8 changed to 12. Both 2s changed to 4 to make deeper.
    translate([ wall_thickness - 3,
                -epsilon,
                pcb_height]) {
        cube([  3 + epsilon,
                pillar_width + 2*epsilon,
                14]);
    }
    
    //Readyformed: Added second slot on right hand side in case Pi needs to be reversed or other cards used.
    translate([ wall_thickness +57,
                -epsilon,
                pcb_height]) {
        cube([  4 + epsilon,
                pillar_width + 2*epsilon,
                14]);
    }


    
    // soften the leading edge a bit
    translate([ wall_thickness,
                0,
                floor_depth-0.5]) {
        rotate([25,0,0]) {
            cube([  inner_width,
                    2,
                    2]);
        }
    }

    // drill the bolt holes
    //Readyformed: -2 added to move bolts slightly lower, a+1 added to move bolts slightly tiwards rear.
    for (a=[bolt_column_size/2, length-bolt_column_size/2]) {
        translate([-epsilon, a+1, floor_depth - bolt_column_size/2-2]) {
            rotate([0, 90, 0]) {
                cylinder(   h=outer_width + 2*epsilon,
                            r=bolt_radius,
                            center=false,
                            $fn=360);
            }
        }
    }
    
    // trim the bolt hole columns
    // Readyformed: remmed out to make front flat to cover new gap for screws.
   * for (a=[0, bolt_column_size, length-bolt_column_size, length]) {
        translate([-epsilon, a, floor_depth - bolt_column_size - 4]) {
            rotate([45, 0, 0]) {
                cube([outer_width + 2*epsilon, 5, 5]);
            }
        }
    }

    // cut the tray insert slots
    // note: the tray will be slightly narrower to
    // give a more comfortable fit. If it is too loose or too tight,
    // adjust the tray.
    for (a=[    wall_thickness,
                inner_width + wall_thickness]) {
        translate([ a,
                    -epsilon,
                    floor_depth + tray_depth/2]) {
            intersection() {
                rotate([0, 45, 0]) {
                    translate([-tray_depth/sqrt(2)/2, 0, -tray_depth/sqrt(2)/2]) {
                        cube([  tray_depth/sqrt(2),
                                length - back_wall_thickness + epsilon,
                                tray_depth/sqrt(2)]);
                    }
                }
                translate([-tray_depth/2+0.5, 0, -tray_depth/2]) {
                    cube([  tray_depth-1,
                            length - back_wall_thickness + epsilon,
                            tray_depth]);
                }
            }
        }
    }
}



rotate([90,0,0]) translate([36,-6,0])  { 
      linear_extrude(1) text("READYFORMED", size=5, halign="center", direction="ltr"); }

